@@ -232,7 +232,6 @@ def subcommand_convert(args):
                     print ('written new config to <%s>.' % (newfile))
 
 
-
 def subcommand_attach_session(args):
     commands = []
     try:
@@ -264,11 +263,10 @@ def subcommand_kill_session(args):
     sessions = [s for s in t.sessions if s.get('session_name') == ctext]
 
     if (len(sessions) == 1):
-        proc = sessions[0].kill_session()
-        if proc.stderr:
-            print(proc.stderr)
-
-        print(proc.stdout)
+        try:
+            sessions[0].kill_session()
+        except Exception as e:
+            logger.error(e)
 
 
 def cli_parser():
@@ -370,6 +368,7 @@ def main():
     args = parser.parse_args()
 
     setupLogger(level=args.log_level.upper())
+    logger.error('hi')
     try:
         util.version()
     except Exception as e:
@@ -433,8 +432,11 @@ def complete(cline, cpoint):
             commands[:] = []
             ctext_subargs = ctext.replace(command + ' ', '')
 
-            sessions = [s.get('session_name') for s in t._sessions]
-            commands.extend([c for c in sessions if ctext_subargs in c])
+            try:
+                sessions = [s.get('session_name') for s in t._sessions]
+                commands.extend([c for c in sessions if ctext_subargs in c])
+            except Exception:
+                pass
 
     def config_complete(command, commands, ctext):
         if ctext.startswith(command + ' '):
